==> unicore-uvos-server-1.5.1-0.src.tar.gz: src/test/java/pl/edu/icm/unicore/uvos/tests/functional/AttributeFunctionalTest.java <==
/*
 * Copyright (c) 2007, 2008 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on Sep 20, 2007
 * Author: K. Benedyczak <golbi@mat.umk.pl>
 */

package pl.edu.icm.unicore.uvos.tests.functional;

import java.io.FileInputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import org.junit.Test;

import eu.unicore.bugsreporter.annotation.RegressionTest;

import static junit.framework.Assert.*;

import pl.edu.icm.unicore.uvos.api.Attribute;
import pl.edu.icm.unicore.uvos.api.AttributeType;
import pl.edu.icm.unicore.uvos.api.Element;
import pl.edu.icm.unicore.uvos.api.Identity;
import pl.edu.icm.unicore.uvos.api.IdentityType;
import pl.edu.icm.unicore.uvos.api.exceptions.ElementAlreadyExistsException;
import pl.edu.icm.unicore.uvos.api.exceptions.ElementNotKnownException;
import pl.edu.icm.unicore.uvos.api.exceptions.InternalException;
import pl.edu.icm.unicore.uvos.api.exceptions.InvalidValueException;
import pl.edu.icm.unicore.uvos.api.exceptions.LabelAlreadyUsedException;
import pl.edu.icm.unicore.uvos.api.exceptions.SecurityException;
import pl.edu.icm.unicore.uvos.api.exceptions.UnsupportedTypeException;


/**
 * Performs functional tests. Assumptions:
 * Server is up and running and DB is empty
 * @author K. Benedyczak
 */
public class AttributeFunctionalTest extends AbstractTestBase
{
	private String atPrefix;
	private AttributeType atType;
	private byte binVal[] = new byte[256];
	
	@RegressionTest(url="http://sourceforge.net/tracker/?func=detail&aid=3041189&group_id=102081&atid=633902",
			description="tstAttrs() does the regression test")
	@Test
	public void testAll()
	{
		for (int i=0; i<255; i++)
			binVal[i] = (byte)(i+1);
		try
		{
			createTestGI();
			atPrefix = "test:attribute";
			atType = voMan.getAttributeTypes().get(0);
			tstAttrs();
			tstGeneratedAttrs();
			cleanTestGI();
		} catch (Exception e)
		{
			e.printStackTrace();
			fail("Exception: " + e.getMessage());
		}
	}

	private void tstAttrs() throws Exception
	{
		config.setProperty("uvos.server.generateAttributesFromDN", "false");
		voMan.addToGroup(idA1, gC);
		voMan.addToGroup(idB, gA);
		List<String> vals1 = new ArrayList<String>();
		vals1.add(new String(binVal));
		vals1.add("<>~`!@#$%^&*()<!-- -->,<.>/?';:[{]}\\=-");
		List<String> vals2 = new ArrayList<String>();
		vals2.add("A1");
		Attribute attr1 = new Attribute(atType, vals1, "/A/B/C");
		Attribute attr2 = new Attribute(atPrefix + ":attr2", null, "/A");
		Attribute attr3 = new Attribute(atPrefix + ":attr3", vals1, null);
		Attribute attr4 = new Attribute(atPrefix + ":attr4", null, "/A/B");
		Attribute attr5 = new Attribute(atPrefix + ":attr5", null, "/A/B/C");
		Attribute attr5vals = new Attribute(atPrefix + ":attr5", vals1, "/A/B/C");
		Attribute attr5vals2 = new Attribute(atPrefix + ":attr5", vals2, null);
		Element elGc = new Element(gC, null);
		Element elGa = new Element(gA, null);
		Element elIa2 = new Element(null, idA2);
		Element elidBingB = new Element(gB, idB);
		Element elidAingC = new Element(gC, idA2);
		
		voMan.setAttribute(elGc, attr1, false);
		List<Attribute> al1 = voQuery.getAttributes(elGc, null, false, false, false);
		if (al1.size() != 1 || !al1.get(0).equals(attr1))
			fail("Wrong attr result of exact group attrs: " + al1.size() + 
					" " + al1.get(0));
		al1 = voQuery.getAttributes(elGc, null, true, false, false);
		if (al1.size() != 1 || !al1.get(0).equals(attr1))
			fail("Wrong attr result of effective group attrs");
		
		voMan.setAttribute(elGa, attr2, false);
		al1 = voQuery.getAttributes(elGa, null, false, false, false);
		if (al1.size() != 1 || !al1.get(0).equals(attr2))
			fail("Wrong attr result of exact group attrs");
		al1 = voQuery.getAttributes(elGa, null, true, false, false);
		if (al1.size() != 1 || !al1.get(0).equals(attr2))
			fail("Wrong attr result of effective group attrs");
		
		al1 = voQuery.getAttributes(new Element(gA, idA2), null, true, false, false);
		if (al1.size() != 2)
			fail("Wrong number of attrs received (group (1))");
		al1 = voQuery.getAttributes(new Element(gB, idA2), null, true, false, false);
		if (al1.size() != 1)
			fail("Wrong number of attrs received (group (2))");
		al1 = voQuery.getAttributes(elidAingC, null, true, false, false);
		if (al1.size() != 1)
			fail("Wrong number of attrs received (group (3))");

		al1 = voQuery.getAttributes(new Element(gA, idB), null, true, false, false);
		if (al1.size() != 1)
			fail("Wrong number of attrs received (group (4))");
		al1 = voQuery.getAttributes(new Element(gB, idB), null, true, false, false);
		if (al1.size() != 0)
			fail("Wrong number of attrs received (group (5))");
		al1 = voQuery.getAttributes(new Element(gC, idB), null, true, false, false);
		if (al1.size() != 0)
			fail("Wrong number of attrs received (group (6))");
		
		
		voMan.setAttribute(elIa2, attr3, false);
		al1 = voQuery.getAttributes(new Element(gA, idA2), null, true, false, false);
		if (al1.size() != 3)
			fail("Wrong number of attrs received (group (1))");
		al1 = voQuery.getAttributes(elidAingC, null, true, false, false);
		if (al1.size() != 2)
			fail("Wrong number of attrs received (group (3))");
		al1 = voQuery.getAttributes(elIa2, null, true, false, false);
		if (al1.size() != 1)
			fail("Wrong number of attrs received (group (2))");
		
		//setting id@gr attr when id isn't gr member should succeed, but this
		//attribute should be reported only in exact query, not in effective.
		voMan.setAttribute(elidBingB, attr4, false);
		al1 = voQuery.getAttributes(elidBingB, null, true, false, false);
		if (al1.size() != 0)
			fail("Wrong number of Attrs received (id@group effective (1)) " + 
					al1.size());
		al1 = voQuery.getAttributes(elidBingB, null, false, false, false);
		if (al1.size() != 1 || !al1.get(0).equals(attr4))
			fail("Wrong number or Attr received (id@group exact (2))");

		voMan.setAttribute(elidAingC, attr5, false);
		al1 = voQuery.getAttributes(elidAingC, null, true, false, false);
		if (al1.size() != 3)
			fail("Wrong number attrs received (id@group effective (3)) " + 
					al1.size());
		al1 = voQuery.getAttributes(elidAingC, null, false, false, false);
		if (al1.size() != 1 || !al1.get(0).equals(attr5))
			fail("Wrong number or Attr received (id@group exact (4))");
		
		voMan.setAttribute(elidAingC, attr5vals, true);
		List<Attribute> attr = voQuery.getAttributes(elidAingC, 
				attr5.getName(), true, false, false);
		if (attr == null || attr.size() != 1 || !attr.get(0).equals(attr5vals))
			fail("Update attr error (1)");
		attr = voQuery.getAttributes(elidAingC, attr5.getName(), false, 
				false, false);
		if (attr == null || attr.size() != 1 || !attr.get(0).equals(attr5vals))
			fail("Update attr error (2)");
		
		voMan.setAttribute(elGc, attr5vals2, true);
		attr = voQuery.getAttributes(new Element(gA, idA2), 
				attr5.getName(), true, false, false);
		if (attr == null || attr.size() != 1)
			fail("Sum of attr error (1)");
		if (attr.get(0).getValues().size() != 2)
			fail("Sum of attr error (2): " + attr.get(0).getValues().size());
		
		//check of global requests, with all groups scopping
		al1 = voQuery.getAttributes(elIa2, null, true, true, false);
		if (al1.size() != 4)
			fail("Wrong number attrs received (id, all scopes (1)) " + 
					printAtrs(al1));
		al1 = voQuery.getAttributes(elIa2, null, true, true, true);
		if (al1.size() != 11)
			fail("Wrong number attrs received (id, all scopes (2)) " +
					printAtrs(al1));
		
		al1 = voQuery.getAttributes(elIa2, attr1.getName(), true, true, false);
		if (al1.size() != 1)
			fail("Wrong number attrs received (id, all scopes (3)) " + 
					printAtrs(al1));
		al1 = voQuery.getAttributes(elIa2, attr2.getName(), true, true, true);
		if (al1.size() != 1)
			fail("Wrong number attrs received (id, all scopes (4)) " +
					printAtrs(al1));
		al1 = voQuery.getAttributes(elIa2, attr2.getName(), true, true, false);
		if (al1.size() != 0)
			fail("Wrong number attrs received (id, all scopes (5)) " + 
					printAtrs(al1));

		voMan.removeAttribute(elGc, attr1.getName());
		voMan.removeAttribute(elGa, attr2.getName());
		voMan.removeAttribute(elIa2, attr3.getName());
		voMan.removeAttribute(elidBingB, attr4.getName());
		voMan.removeAttribute(elidAingC, attr5.getName());
		voMan.removeAttribute(elGc, attr5vals2.getName());
		al1 = voQuery.getAttributes(elidAingC, null, true, false, false);
		if (al1.size() != 0)
			fail("Wrong number attrs received (removal (1)) " + 
					al1.size());
		al1 = voQuery.getAttributes(elGc, null, true, false, false);
		if (al1.size() != 0)
			fail("Wrong number attrs received (removal (2)) " + 
					al1.size());
		al1 = voQuery.getAttributes(elIa2, null, true, false, false);
		if (al1.size() != 0)
			fail("Wrong number attrs received (removal (3)) " + 
					al1.size());
	}
	
	private void tstGeneratedAttrs() throws IOException, SecurityException, InternalException, ElementAlreadyExistsException, UnsupportedTypeException, LabelAlreadyUsedException, InvalidValueException, ElementNotKnownException
	{
		config.setProperty("uvos.server.generateAttributesFromDN", "true");
		FileInputStream fis = new FileInputStream("src/test/resources/certs/pubCert.pem");
		int len = fis.available();
		byte []buffer = new byte[len];
		fis.read(buffer);
		Identity []ids = new Identity[3];
		List<HashMap<String, String>> hashMaps = new ArrayList<HashMap<String,String>>();
		
		ids[0] = new Identity(IdentityType.DN, "cn=ala,c=pl,ou=icm", null);
		HashMap<String, String> hm = new HashMap<String, String>();
		hm.put("cn", "ala");
		hm.put("c", "pl");
		hm.put("ou", "icm");
		hashMaps.add(hm);
		
		ids[1] = new Identity(IdentityType.X509CERT, new String(buffer), null);
		hm = new HashMap<String, String>();
		hm.put("c", "PL");
		hm.put("st", "Example Province");
		hm.put("l", "Example City");
		hm.put("o", "Example O");
		hm.put("ou", "Example OU");
		hm.put("cn", "Example Client");
		hashMaps.add(hm);
		
		ids[2] = new Identity(IdentityType.EMAIL, "a@b", null);
		hm = new HashMap<String, String>();
		hm.put("mail", "a@b");
		hashMaps.add(hm);
		
		for(int i=0;i<ids.length;i++)
		{
			voMan.addIdentity(ids[i]);
			Element e = new Element(null, ids[i]);
			List<Attribute> attrs = voQuery.getAttributes(e, null, false, false, false);
			hm = hashMaps.get(i);
			if(attrs.size() != hm.size())
				fail("Wrong attr result of identity generated attrs: " + attrs.size());
			for(Attribute a : attrs)
			{
				String typeName = a.getType().getName();
				if(!hm.containsKey(typeName))
					fail("Invalid attr: " + typeName);
				else if(!hm.get(typeName).equals(a.getValues().get(0)))
					fail("Invalid attr: " + typeName + "=" + a.getValues().get(0));
			}
			voMan.removeIdentity(ids[i]);
		}
		config.setProperty("uvos.server.generateAttributesFromDN", "false");
	}

	private String printAtrs(List<Attribute> print)
	{
		String ret = "Attributes received (" + print.size() + "):\n";
		for (Attribute a: print)
			ret += a + "\n";
		return ret;
	}
}

==> unicore-uvos-server-1.6.0-0.src.tar.gz: src/test/java/pl/edu/icm/unicore/uvos/tests/functional/AttributeFunctionalTest.java <==
/*
 * Copyright (c) 2007, 2008 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on Sep 20, 2007
 * Author: K. Benedyczak <golbi@mat.umk.pl>
 */

package pl.edu.icm.unicore.uvos.tests.functional;

import java.io.FileInputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import org.junit.Test;

import eu.unicore.bugsreporter.annotation.RegressionTest;

import static junit.framework.Assert.*;

import pl.edu.icm.unicore.uvos.api.Attribute;
import pl.edu.icm.unicore.uvos.api.AttributeType;
import pl.edu.icm.unicore.uvos.api.Element;
import pl.edu.icm.unicore.uvos.api.Identity;
import pl.edu.icm.unicore.uvos.api.IdentityType;
import pl.edu.icm.unicore.uvos.api.exceptions.ElementAlreadyExistsException;
import pl.edu.icm.unicore.uvos.api.exceptions.ElementNotKnownException;
import pl.edu.icm.unicore.uvos.api.exceptions.InternalException;
import pl.edu.icm.unicore.uvos.api.exceptions.InvalidValueException;
import pl.edu.icm.unicore.uvos.api.exceptions.LabelAlreadyUsedException;
import pl.edu.icm.unicore.uvos.api.exceptions.SecurityException;
import pl.edu.icm.unicore.uvos.api.exceptions.UnsupportedTypeException;
import pl.edu.icm.unicore.uvos.util.UVOSServerProperties;


/**
 * Performs functional tests. Assumptions:
 * Server is up and running and DB is empty
 * @author K. Benedyczak
 */
public class AttributeFunctionalTest extends AbstractTestBase
{
	private String atPrefix;
	private AttributeType atType;
	private byte binVal[] = new byte[256];
	
	@RegressionTest(url="http://sourceforge.net/tracker/?func=detail&aid=3041189&group_id=102081&atid=633902",
			description="tstAttrs() does the regression test")
	@Test
	public void testAll()
	{
		for (int i=0; i<255; i++)
			binVal[i] = (byte)(i+1);
		try
		{
			createTestGI();
			atPrefix = "test:attribute";
			atType = voMan.getAttributeTypes().get(0);
			tstAttrs();
			tstGeneratedAttrs();
			cleanTestGI();
		} catch (Exception e)
		{
			e.printStackTrace();
			fail("Exception: " + e.getMessage());
		}
	}

	private void tstAttrs() throws Exception
	{
		config.setProperty(UVOSServerProperties.GENERATE_ATTRIBUTES_FROM_DN, "false");
		voMan.addToGroup(idA1, gC);
		voMan.addToGroup(idB, gA);
		List<String> vals1 = new ArrayList<String>();
		vals1.add(new String(binVal));
		vals1.add("<>~`!@#$%^&*()<!-- -->,<.>/?';:[{]}\\=-");
		List<String> vals2 = new ArrayList<String>();
		vals2.add("A1");
		Attribute attr1 = new Attribute(atType, vals1, "/A/B/C");
		Attribute attr2 = new Attribute(atPrefix + ":attr2", null, "/A");
		Attribute attr3 = new Attribute(atPrefix + ":attr3", vals1, null);
		Attribute attr4 = new Attribute(atPrefix + ":attr4", null, "/A/B");
		Attribute attr5 = new Attribute(atPrefix + ":attr5", null, "/A/B/C");
		Attribute attr5vals = new Attribute(atPrefix + ":attr5", vals1, "/A/B/C");
		Attribute attr5vals2 = new Attribute(atPrefix + ":attr5", vals2, null);
		Element elGc = new Element(gC, null);
		Element elGa = new Element(gA, null);
		Element elIa2 = new Element(null, idA2);
		Element elidBingB = new Element(gB, idB);
		Element elidAingC = new Element(gC, idA2);
		
		voMan.setAttribute(elGc, attr1, false);
		List<Attribute> al1 = voQuery.getAttributes(elGc, null, false, false, false);
		if (al1.size() != 1 || !al1.get(0).equals(attr1))
			fail("Wrong attr result of exact group attrs: " + al1.size() + 
					" " + al1.get(0));
		al1 = voQuery.getAttributes(elGc, null, true, false, false);
		if (al1.size() != 1 || !al1.get(0).equals(attr1))
			fail("Wrong attr result of effective group attrs");
		
		voMan.setAttribute(elGa, attr2, false);
		al1 = voQuery.getAttributes(elGa, null, false, false, false);
		if (al1.size() != 1 || !al1.get(0).equals(attr2))
			fail("Wrong attr result of exact group attrs");
		al1 = voQuery.getAttributes(elGa, null, true, false, false);
		if (al1.size() != 1 || !al1.get(0).equals(attr2))
			fail("Wrong attr result of effective group attrs");
		
		al1 = voQuery.getAttributes(new Element(gA, idA2), null, true, false, false);
		if (al1.size() != 2)
			fail("Wrong number of attrs received (group (1))");
		al1 = voQuery.getAttributes(new Element(gB, idA2), null, true, false, false);
		if (al1.size() != 1)
			fail("Wrong number of attrs received (group (2))");
		al1 = voQuery.getAttributes(elidAingC, null, true, false, false);
		if (al1.size() != 1)
			fail("Wrong number of attrs received (group (3))");

		al1 = voQuery.getAttributes(new Element(gA, idB), null, true, false, false);
		if (al1.size() != 1)
			fail("Wrong number of attrs received (group (4))");
		al1 = voQuery.getAttributes(new Element(gB, idB), null, true, false, false);
		if (al1.size() != 0)
			fail("Wrong number of attrs received (group (5))");
		al1 = voQuery.getAttributes(new Element(gC, idB), null, true, false, false);
		if (al1.size() != 0)
			fail("Wrong number of attrs received (group (6))");
		
		
		voMan.setAttribute(elIa2, attr3, false);
		al1 = voQuery.getAttributes(new Element(gA, idA2), null, true, false, false);
		if (al1.size() != 3)
			fail("Wrong number of attrs received (group (1))");
		al1 = voQuery.getAttributes(elidAingC, null, true, false, false);
		if (al1.size() != 2)
			fail("Wrong number of attrs received (group (3))");
		al1 = voQuery.getAttributes(elIa2, null, true, false, false);
		if (al1.size() != 1)
			fail("Wrong number of attrs received (group (2))");
		
		//setting id@gr attr when id isn't gr member should succeed, but this
		//attribute should be reported only in exact query, not in effective.
		voMan.setAttribute(elidBingB, attr4, false);
		al1 = voQuery.getAttributes(elidBingB, null, true, false, false);
		if (al1.size() != 0)
			fail("Wrong number of Attrs received (id@group effective (1)) " + 
					al1.size());
		al1 = voQuery.getAttributes(elidBingB, null, false, false, false);
		if (al1.size() != 1 || !al1.get(0).equals(attr4))
			fail("Wrong number or Attr received (id@group exact (2))");

		voMan.setAttribute(elidAingC, attr5, false);
		al1 = voQuery.getAttributes(elidAingC, null, true, false, false);
		if (al1.size() != 3)
			fail("Wrong number attrs received (id@group effective (3)) " + 
					al1.size());
		al1 = voQuery.getAttributes(elidAingC, null, false, false, false);
		if (al1.size() != 1 || !al1.get(0).equals(attr5))
			fail("Wrong number or Attr received (id@group exact (4))");
		
		voMan.setAttribute(elidAingC, attr5vals, true);
		List<Attribute> attr = voQuery.getAttributes(elidAingC, 
				attr5.getName(), true, false, false);
		if (attr == null || attr.size() != 1 || !attr.get(0).equals(attr5vals))
			fail("Update attr error (1)");
		attr = voQuery.getAttributes(elidAingC, attr5.getName(), false, 
				false, false);
		if (attr == null || attr.size() != 1 || !attr.get(0).equals(attr5vals))
			fail("Update attr error (2)");
		
		voMan.setAttribute(elGc, attr5vals2, true);
		attr = voQuery.getAttributes(new Element(gA, idA2), 
				attr5.getName(), true, false, false);
		if (attr == null || attr.size() != 1)
			fail("Sum of attr error (1)");
		if (attr.get(0).getValues().size() != 2)
			fail("Sum of attr error (2): " + attr.get(0).getValues().size());
		
		//check of global requests, with all groups scopping
		al1 = voQuery.getAttributes(elIa2, null, true, true, false);
		if (al1.size() != 4)
			fail("Wrong number attrs received (id, all scopes (1)) " + 
					printAtrs(al1));
		al1 = voQuery.getAttributes(elIa2, null, true, true, true);
		if (al1.size() != 11)
			fail("Wrong number attrs received (id, all scopes (2)) " +
					printAtrs(al1));
		
		al1 = voQuery.getAttributes(elIa2, attr1.getName(), true, true, false);
		if (al1.size() != 1)
			fail("Wrong number attrs received (id, all scopes (3)) " + 
					printAtrs(al1));
		al1 = voQuery.getAttributes(elIa2, attr2.getName(), true, true, true);
		if (al1.size() != 1)
			fail("Wrong number attrs received (id, all scopes (4)) " +
					printAtrs(al1));
		al1 = voQuery.getAttributes(elIa2, attr2.getName(), true, true, false);
		if (al1.size() != 0)
			fail("Wrong number attrs received (id, all scopes (5)) " + 
					printAtrs(al1));

		voMan.removeAttribute(elGc, attr1.getName());
		voMan.removeAttribute(elGa, attr2.getName());
		voMan.removeAttribute(elIa2, attr3.getName());
		voMan.removeAttribute(elidBingB, attr4.getName());
		voMan.removeAttribute(elidAingC, attr5.getName());
		voMan.removeAttribute(elGc, attr5vals2.getName());
		al1 = voQuery.getAttributes(elidAingC, null, true, false, false);
		if (al1.size() != 0)
			fail("Wrong number attrs received (removal (1)) " + 
					al1.size() + " " + al1.get(0));
		al1 = voQuery.getAttributes(elGc, null, true, false, false);
		if (al1.size() != 0)
			fail("Wrong number attrs received (removal (2)) " + 
					al1.size());
		al1 = voQuery.getAttributes(elIa2, null, true, false, false);
		if (al1.size() != 0)
			fail("Wrong number attrs received (removal (3)) " + 
					al1.size());
	}
	
	private void tstGeneratedAttrs() throws IOException, SecurityException, InternalException, ElementAlreadyExistsException, UnsupportedTypeException, LabelAlreadyUsedException, InvalidValueException, ElementNotKnownException
	{
		config.setProperty(UVOSServerProperties.GENERATE_ATTRIBUTES_FROM_DN, "true");
		FileInputStream fis = new FileInputStream("src/test/resources/certs/pubCert.pem");
		int len = fis.available();
		byte []buffer = new byte[len];
		fis.read(buffer);
		Identity []ids = new Identity[3];
		List<HashMap<String, String>> hashMaps = new ArrayList<HashMap<String,String>>();
		
		ids[0] = new Identity(IdentityType.DN, "cn=ala,c=pl,ou=icm", null);
		HashMap<String, String> hm = new HashMap<String, String>();
		hm.put("cn", "ala");
		hm.put("c", "pl");
		hm.put("ou", "icm");
		hashMaps.add(hm);
		
		ids[1] = new Identity(IdentityType.X509CERT, new String(buffer), null);
		hm = new HashMap<String, String>();
		hm.put("c", "PL");
		hm.put("st", "Example Province");
		hm.put("l", "Example City");
		hm.put("o", "Example O");
		hm.put("ou", "Example OU");
		hm.put("cn", "Example Client");
		hashMaps.add(hm);
		
		ids[2] = new Identity(IdentityType.EMAIL, "a@b", null);
		hm = new HashMap<String, String>();
		hm.put("mail", "a@b");
		hashMaps.add(hm);
		
		for(int i=0;i<ids.length;i++)
		{
			voMan.addIdentity(ids[i]);
			Element e = new Element(null, ids[i]);
			List<Attribute> attrs = voQuery.getAttributes(e, null, false, false, false);
			hm = hashMaps.get(i);
			if(attrs.size() != hm.size())
				fail("Wrong attr result of identity generated attrs: " + attrs.size());
			for(Attribute a : attrs)
			{
				String typeName = a.getType().getName();
				if(!hm.containsKey(typeName))
					fail("Invalid attr: " + typeName);
				else if(!hm.get(typeName).equals(a.getValues().get(0)))
					fail("Invalid attr: " + typeName + "=" + a.getValues().get(0));
			}
			voMan.removeIdentity(ids[i]);
		}
		config.setProperty(UVOSServerProperties.GENERATE_ATTRIBUTES_FROM_DN, "false");
	}

	private String printAtrs(List<Attribute> print)
	{
		String ret = "Attributes received (" + print.size() + "):\n";
		for (Attribute a: print)
			ret += a + "\n";
		return ret;
	}
}
